@@ -19,30 +19,13 @@ import shutil
 import sys
 
 from digital_hydrant import logging
-from digital_hydrant.scheduler import Scheduler
 from digital_hydrant.uploader import Uploader
 from digital_hydrant.collector_queue import CollectorQueue
 from digital_hydrant.ping import Ping
 from digital_hydrant.args import args
 from digital_hydrant.process_manager import ProcessManager
 from digital_hydrant.config import db_path, update_config, check_default_config
-
-
-def create_tables(logger):
-    tables = {
-        "unique_ips": "id INTEGER PRIMARY KEY AUTOINCREMENT, ip TEXT UNIQUE, last_tested TIMESTAMP, last_nmap_scan TIMESTAMP, open_ports TEXT",
-        "collectors": "id INTEGER PRIMARY KEY AUTOINCREMENT, type TEXT, payload TEXT, timestamp TIMESTAMP, uploaded INTEGER DEFAULT 0",
-    }
-
-    try:
-        conn = sqlite3.connect(db_path)
-        cursor = conn.cursor()
-
-        for table_name, columns in tables.items():
-            cursor.execute(f"CREATE TABLE IF NOT EXISTS {table_name} ({columns})")
-
-    except Exception as e:
-        logger.critical(f"Failed to initialize databases: {err}")
+from digital_hydrant.migration import migrate_db
 
 
 def check_required_ubuntu_packages():
@@ -73,6 +56,8 @@ def check_required_ubuntu_packages():
 
 def run():
     check_default_config()
+    migrate_db()
+
     missing = False if args.force else check_required_ubuntu_packages()
 
     if args.init is not None:
@@ -89,13 +74,11 @@ def run():
 
     logger = logging.getLogger(__name__)
     manager = ProcessManager("Main")
-    create_tables(logger)
 
     if args.clear_queue:
         queue = CollectorQueue()
         queue.remove_all()
 
-    # ping the server
     ping = Ping()
     manager.add_process("ping", ping.__exec__)
 
@@ -106,12 +89,12 @@ def run():
         collect = upload = True
 
     if collect:
-        scheduler = Scheduler()
-        manager.add_process("scheduler", scheduler.__schedule__)
+        logger.info("Launching Scheduler")
+        scheduler = ProcessManager("Scheduler")
+        manager.add_process("scheduler", scheduler.manage)
 
     if upload:
         logger.info("Launching Uploader")
-        # upload data to the api
         uploader = Uploader()
         manager.add_process("uploader", uploader.__upload__)
 
